@@ -7,7 +7,7 @@ import functools
 import types
 import warnings
 
-__version__ = "2.4.1"
+__version__ = "2.4.2"
 
 # from https://github.com/python/cpython/blob/main/Lib/_collections_abc.py
 # missing from python < 3.6
@@ -428,8 +428,8 @@ class ArgumentParser(argparse.ArgumentParser):
         for attr,val in six.iteritems(flat_vars):
             if attr in self._dests_actions or attr in self._config_only:
                 tmp = val
-                # check type if uniquely provided
-                if len(self._dests_actions[attr])==1 or len(set([action.type for action in self._dests_actions[attr]]))==1:
+                # check type if uniquely provided (and not None)
+                if (len(self._dests_actions[attr])==1 or len(set([action.type for action in self._dests_actions[attr]]))==1) and self._dests_actions[attr][0].type is not None:
                     # use _get_values() rather than _get_value() to handle nargs cases; also enforces choices if any
                     tmp_action = self._dests_actions[attr][0]
                     # argparse does not apply type or choice checks to default args
@@ -441,7 +441,7 @@ class ArgumentParser(argparse.ArgumentParser):
                         tmp = bool(tmp)
                     # generically handle any other cases with nargs=0
                     elif tmp_action.nargs==0:
-                        if action.type: tmp = action.type(tmp)
+                        if tmp_action.type: tmp = tmp_action.type(tmp)
                     else:
                         # _get_values() expects a list
                         if not isinstance(tmp,list): tmp = [tmp]
